#ifndef __KEYBOARD_CONTROLLER_H
#define __KEYBOARD_CONTROLLER_H

#ifdef HAVE_VIEWER

#include "Controller.h"

/*!	\file Keyboard.h
	\brief Interface of the Keyboard Controller
*/

namespace Teem
{
	/** A controller that allows the user to control the robot with the cursor keys on the keyboard. Very useful for testing. Implement a differential wheeled robot model where the keyboard arrows set output[0] and output[1] corresponding to virtual left and right speeds
		\ingroup controllers
	*/
	class KeyboardController : public Controller
	{
	public:
		//! Constructor takes the runningSpeed (in cm/s) and turningSpeed as input (in rad/s (?))
		KeyboardController(double runningSpeed, double turningSpeed);
		//! Destructor
		virtual ~KeyboardController();
		
		//! Do not call. A keyboard in Teem has no inputs, only outputs
		virtual void setInput(unsigned index, double val)
		{
			assert(false);
		}
		
		//! Get output corresponding to arrows keys
		virtual double getOutput(unsigned index)
		{
			assert(index < 2);
			return output[index];
		}
		
		virtual void step();
		
		double runningSpeed; //!< forward speed
		double turningSpeed; //!< rotation speed
		
	protected:
		double output[2]; //!< virtual left and right speed
	};
}

#endif // HAVE_VIEWER

#endif
