#include <ishtar/settings.h>

#include "SigmoidNeuron.h"
#include <cmath>

/*!	\file SigmoidNeuron.cpp
	\brief Implementation of sigmoid neurons
*/

namespace Teem
{
	SigmoidNeuron::SigmoidNeuron() :
		alpha("teem.nn.sigmoid.alpha", 1.0)
	{
		// state
		activation = 0.0;
	}
	
	void SigmoidNeuron::setParams(const std::string &param, double value)
	{
		if(param == "alpha")
			alpha = value;
		else
			Neuron::setParams(param, value);
	}
	
	void SigmoidNeuron::update(double dt)
	{
		// compute activation
		for (SynapseSet::iterator p = incoming.begin(); p != incoming.end(); ++p)
		{
			Synapse* synapse = *p;
			activation += synapse->weight * synapse->getCurrent();
		}
	}
	
	void SigmoidNeuron::commit()
	{
		lastCurrent = tanh(alpha * activation);
		activation = 0.0;
	}
}
