#ifndef __NEURAL_NETWORK_DRAWER_H
#define __NEURAL_NETWORK_DRAWER_H

#ifdef HAVE_VIEWER
#include <ishtar/services.h>
#include "../libgag/GAG.h"
#include "../controller/nn/FeedForwardNeuralNetwork.h"

namespace Teem
{
	//! Draw neural network in matrix form
	class NeuralNetworkDrawer
	{
	public:
		//! Init and draw controller nn.
		NeuralNetworkDrawer(GAG::GraphicContext *gc, int x, int y, int w, int h, Controller* nn, double colorScale = 2.0);
		//! Init and draw nothing. Use drawCell function to draw something.
		NeuralNetworkDrawer(GAG::GraphicContext *gc, int x, int y, int w, int h, double colorScale = 2.0);
		
		//! draw a single cell.
		void drawCell(int cx, int cy, bool round, double color = 0.0);
		
	protected:
		GAG::GraphicContext *gc; //!< graphic context to draw on
		//! position and size
		int x, y, w, h;
		double colorScale; //!< synapse weight to color coefficient
		int cellSize; //!< maximum size of cell
		
		//! Draw the feed-forward neural network ffnn
		void drawFeedForwardNeuralNetwork(FeedForwardNeuralNetwork* ffnn);
		//! Draw the recurrent feed-forward neural network rffnn
		void drawRecurrencyFromFeedForwardNeuralNetwork(RecurrentFeedForwardNeuralNetwork* rffnn);
	};
}

#endif
#endif
