#include "SVGPlotter.h"
#include <assert.h>

/*!	\file SVGPlotter.cpp
	\brief Implementation of a simple SVG renderer
*/

namespace Teem
{
	SVGPlotter::SVGPlotter(const std::string &filename, double width, double height) :
		outputFile(filename.c_str())
	{
		outputFile << "<?xml version=\"1.0\" standalone=\"no\"?>\n";
		outputFile << "<!DOCTYPE svg PUBLIC \"-//W3C//DTD SVG 1.1//EN\"\n";
		outputFile << "\"http://www.w3.org/Graphics/SVG/1.1/DTD/svg11.dtd\">\n";
		outputFile << "<svg width=\"" << width << "\" height=\"" << height << "\" x=\"0\" y=\"0\">\n";
	}
	
	SVGPlotter::~SVGPlotter()
	{
		outputFile << "</svg>\n";
	}
	
	size_t SVGPlotter::createTrajectory(double x, double y)
	{
		size_t id = trajectories.size();
		trajectories.push_back(std::pair<double, double>(x, y));
		outputFile << "<circle cx=\"" << x <<
			"\" cy=\"" << y <<
			"\" r=\"3\" stroke=\"black\"/>\n";
		return id;
	}
	
	void SVGPlotter::drawLine(size_t trajectory, double x, double y, double r, double g, double b)
	{
		assert(trajectory < trajectories.size());
		double ox = trajectories[trajectory].first;
		double oy = trajectories[trajectory].second;
		if ((x != ox) || (y != oy))
		{
			outputFile << "<line x1=\"" << ox << 
				"\" y1=\"" << oy << 
				"\" x2=\"" << x <<
				"\" y2=\"" << y <<
				"\" style=\"stroke:rgb(" << static_cast<int>(r * 255.0) <<
				"," << static_cast<int>(g * 255.0) <<
				"," << static_cast<int>(b * 255.0) << ")\"/>\n";
			trajectories[trajectory].first = x;
			trajectories[trajectory].second = y;
		}
	}
}
